# -*- coding: utf-8 -*-
import dash
import dash_core_components as dcc
import dash_html_components as html

# https://github.com/plotly/dash-recipes/blob/master/dash-plotly-132-histogram-data-simple.py

external_stylesheets = ['https://codepen.io/chriddyp/pen/bWLwgP.css']

app = dash.Dash(__name__, external_stylesheets=external_stylesheets)

app.layout = html.Div(children=[
    html.H1(children='UT Austin: Psychology - 2009-2019'),

    html.Div(children='''
        Here is a report that compares UT Austin psychology publications with other institutions.
    '''),

    dcc.Graph(
        id='citation-graph',
        figure={
            'data': [
                {'x': [2015, 2016, 2013, 2014, 2011, 2017, 2010, 2012, 2009, 2018, 2019], 'y': [332, 313, 284, 281, 271, 256, 232, 224, 196, 128, 3], 'type': 'bar', 'name': 'UT Austin'},
                {'x': [2015, 2016, 2014, 2012, 2011, 2013, 2010, 2017, 2009, 2018, 2019], 'y': [161, 157, 148, 145, 133, 128, 115, 113, 112, 60, 3], 'type': 'bar', 'name': 'TAMU'},
            ],
            'layout': {
                'xaxis':{
                    'title':'Year of publication'
                },
                'yaxis':{
                     'title':'Number of citations'
                },
                'title': 'Citations per year',
            }
        }
    ),

    dcc.Graph(
        id='oa-graph',
        figure={
            'data': [
                {'x': [2016, 2015, 2014, 2013, 2011, 2010, 2017, 2012, 2018, 2009, 2019], 'y': [183, 172, 139, 132, 123, 119, 118, 117, 102, 87, 7], 'type': 'bar', 'name': 'UT Austin'},
                {'x': [2015, 2016, 2014, 2017, 2012, 2018, 2011, 2013, 2010, 2009], 'y': [62, 62, 47, 41, 40, 40, 39, 37, 30, 28], 'type': 'bar', 'name': 'TAMU'},
            ],
            'layout': {
                'xaxis':{
                    'title':'Year of publication'
                },
                'yaxis':{
                     'title':'Number of OA publications'
                },
                'title': 'OA publications per year',
            }
        }
    ),

    dcc.Graph(
        id='collab-graph',
        figure={
            'data': [
                {'x': [2018, 2015, 2016, 2017, 2014, 2013, 2011, 2012, 2010, 2008, 2009, 2007, 2004, 2005, 2006, 2002, 2003, 2001, 2019], 'y': [114, 111, 96, 89, 88, 80, 63, 49, 44, 43, 36, 35, 28, 28, 26, 15, 13, 11, 8], 'type': 'bar', 'name': 'International collaborations, UT Austin'},
                {'x': [2018, 2016, 2017, 2015, 2013, 2012, 2011, 2014, 2010, 2009, 2007, 2008, 2006, 2005, 2002, 2003, 2004, 2001, 2019], 'y': [125, 123, 120, 118, 88, 77, 75, 74, 65, 59, 49, 48, 40, 36, 31, 30, 27, 22, 6], 'type': 'bar', 'name': 'International collaborations, TAMU'},
                {'x': [2018, 2017, 2016, 2015, 2014, 2013, 2011, 2010, 2012, 2009, 2008, 2007, 2006, 2005, 2004, 2003, 2001, 2002, 2019], 'y': [273, 270, 250, 247, 207, 192, 185, 167, 162, 137, 124, 123, 112, 108, 103, 88, 69, 64, 13], 'type': 'bar', 'name': 'No international collaborations, UT Austin'},
                {'x': [2015, 2016, 2018, 2017, 2014, 2012, 2011, 2013, 2010, 2008, 2009, 2006, 2004, 2007, 2005, 2001, 2002, 2003, 2019], 'y': [142, 138, 129, 124, 121, 105, 101, 97, 88, 71, 71, 66, 61, 50, 48, 43, 43, 40, 6], 'type': 'bar', 'name': 'No international collaborations, TAMU'},
            ],
            'layout': {
                'xaxis':{
                    'title':'Year of publication'
                },
                'yaxis':{
                     'title':'Number of publications'
                },
                'title': 'International collaborations per year',
            }
        }
    )
])

if __name__ == '__main__':
    app.run_server(debug=True)
