import dash
import dash_core_components as dcc
import dash_html_components as html
import pandas as pd
import plotly.graph_objs as go
from dslquery import dslquery

external_stylesheets = ['https://codepen.io/chriddyp/pen/bWLwgP.css']

app = dash.Dash(__name__, external_stylesheets=external_stylesheets)

altmetric = dslquery("""
     search publications
       where (research_orgs.id = "grid.89336.37")
       and year in [2009 : 2019]
     return publications [doi + FOR + times_cited + altmetric] sort by altmetric
     limit 100
""")

subject = ''

for x in altmetric['publications']:
    try:
        subject = x['FOR'][0]['name']
    except:
        subject = 'Not specified'
        pass
    x['FOR'] = subject

df = pd.DataFrame(altmetric['publications'])

app.layout = html.Div(children=[
    html.H1(children='UT Austin: 2009-2019'),

    html.Div(children='''
    Here is a log normalized scatterplot showcasing UT Austin publications with the highest attention and citations, by subject area.
'''),
    dcc.Graph(
        id='alt-cites',
        figure={
            'data': [
                go.Scatter(
                    x=df[df['FOR'] == i]['altmetric'],
                    y=df[df['FOR'] == i]['times_cited'],
                    text=df[df['FOR'] == i]['FOR'],
                    mode='markers',
                    opacity=0.7,
                    marker={
                        'size': 15,
                        'line': {'width': 0.5, 'color': 'white'}
                    },
                ) for i in df.FOR.unique()
            ],
            'layout': go.Layout(
                xaxis={'type': 'log', 'title': 'AAS'},
                yaxis={'type': 'log', 'title': 'Times Cited'},
                margin={'l': 100, 'b': 40, 't': 10, 'r': 10},
                showlegend=False,
                hovermode='closest'
            )
        }
    )
])

if __name__ == '__main__':
    app.run_server(debug=True)
